@@ -1,14 +1,9 @@
 /*  -*- c++ -*-
     sievejob.h
 
-    Copyright (c) 2002 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2002 Marc Mutz <mutz@kde.org>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License,
-    version 2.0, as published by the Free Software Foundation.
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software Foundation,
-    Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
+    SPDX-License-Identifier: GPL-2.0-only
 */
 
 #ifndef KSIEVE_KMANAGESIEVE_SIEVEJOB_H
@@ -17,20 +12,21 @@
 #include "kmanagesieve_export.h"
 
 #include <QObject>
-#include <QStack>
 #include <QStringList>
 
 #include <QUrl>
 #include <kio/global.h>
 #include <kio/udsentry.h>
 
-namespace KIO {
+namespace KIO
+{
 class Job;
 }
 
 class KJob;
 
-namespace KManageSieve {
+namespace KManageSieve
+{
 class Session;
 
 /**
@@ -157,11 +153,12 @@ Q_SIGNALS:
     void item(KManageSieve::SieveJob *job, const QString &filename, bool active);
 
 private:
+    Q_DISABLE_COPY(SieveJob)
     void setErrorMessage(const QString &str);
 
     //@cond PRIVATE
-    SieveJob(QObject *parent = nullptr);
-    ~SieveJob();
+    explicit SieveJob(QObject *parent = nullptr);
+    ~SieveJob() override;
 
     class Private;
     Private *const d;
