@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef SIEVEACTION_H
 #define SIEVEACTION_H
 
-#include <QObject>
-#include <QUrl>
 #include "autocreatescripts/commonwidgets/sievecommonactioncondition.h"
+#include <QObject>
 class QXmlStreamReader;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveEditorGraphicalModeWidget;
 class SieveAction : public SieveCommonActionCondition
 {
