@@ -1,11 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "addresslineedit.h"
-#include <KLocalizedString>
 #include <KColorScheme>
+#include <KLocalizedString>
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <QHBoxLayout>
 
 using namespace KSieveUi;
@@ -13,9 +14,10 @@ using namespace KSieveUi;
 AddressLineEdit::AddressLineEdit(QWidget *parent)
     : AbstractSelectEmailLineEdit(parent)
 {
-    auto *mainLayout = new QHBoxLayout(this);
+    auto mainLayout = new QHBoxLayout(this);
     mainLayout->setContentsMargins({});
     mLineEdit = new QLineEdit(this);
+    new KPIM::LineEditCatchReturnKey(mLineEdit, this);
     mainLayout->addWidget(mLineEdit);
     mLineEdit->setClearButtonEnabled(true);
     mLineEdit->setPlaceholderText(i18n("Define Email Address..."));
@@ -39,7 +41,7 @@ void AddressLineEdit::verifyAddress()
     QString styleSheet;
     const QString lineEditText = text();
     mEmailIsInvalid = !lineEditText.contains(QLatin1Char('@'));
-    //Fix check multi address
+    // Fix check multi address
     if (mNegativeBackground.isEmpty()) {
         KStatefulBrush bgBrush = KStatefulBrush(KColorScheme::View, KColorScheme::NegativeText);
         mNegativeBackground = QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(this).color().name());
