@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,11 +7,12 @@
 #ifndef REGEXPEDITORLINEEDIT_H
 #define REGEXPEDITORLINEEDIT_H
 
-#include <KSieveUi/AbstractRegexpEditorLineEdit>
 #include "ksieveui_private_export.h"
+#include <KSieveUi/AbstractRegexpEditorLineEdit>
 
 class QLineEdit;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class KSIEVEUI_TESTS_EXPORT RegexpEditorLineEdit : public KSieveUi::AbstractRegexpEditorLineEdit
 {
     Q_OBJECT
