@@ -1,32 +1,20 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef SIEVEEDITORGRAPHICALMODEWIDGET_H
 #define SIEVEEDITORGRAPHICALMODEWIDGET_H
 
+#include "ksieveui_private_export.h"
 #include "sieveeditorgraphicalmodewidgetabstract.h"
 #include "util/sieveimapaccountsettings.h"
-#include "ksieveui_private_export.h"
 class QSplitter;
 class QStackedWidget;
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveScriptPage;
 class SieveScriptListBox;
 class SieveEditorParsingMissingFeatureWarning;
@@ -35,7 +23,7 @@ class KSIEVEUI_TESTS_EXPORT SieveEditorGraphicalModeWidget : public SieveEditorG
     Q_OBJECT
 public:
     explicit SieveEditorGraphicalModeWidget(QWidget *parent = nullptr);
-    ~SieveEditorGraphicalModeWidget();
+    ~SieveEditorGraphicalModeWidget() override;
 
     Q_REQUIRED_RESULT QString script(QStringList &required) const override;
 
