@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,7 +16,8 @@ class QGridLayout;
 class QCheckBox;
 class QXmlStreamReader;
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveHelpButton;
 class SieveGlobalVariableWidget;
 
@@ -34,7 +35,7 @@ public:
     };
 
     explicit SieveGlobalVariableActionWidget(QWidget *parent = nullptr);
-    ~SieveGlobalVariableActionWidget();
+    ~SieveGlobalVariableActionWidget() override;
 
     void generatedScript(QString &script);
     void updateAddRemoveButton(bool addButtonEnabled, bool removeButtonEnabled);
@@ -84,6 +85,7 @@ public Q_SLOTS:
 protected:
     void clearWidget(QWidget *aWidget) override;
     QWidget *createWidget(QWidget *parent) override;
+
 private:
     void reconnectWidget(SieveGlobalVariableActionWidget *w);
     void updateAddRemoveButton();
@@ -94,7 +96,7 @@ class SieveGlobalVariableWidget : public SieveWidgetPageAbstract
     Q_OBJECT
 public:
     explicit SieveGlobalVariableWidget(QWidget *parent = nullptr);
-    ~SieveGlobalVariableWidget();
+    ~SieveGlobalVariableWidget() override;
 
     void generatedScript(QString &script, QStringList &requireModules, bool inForEveryPartLoop) override;
 
