@@ -1,31 +1,32 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sievescriptlistbox.h"
-#include "sievescriptdescriptiondialog.h"
-#include "sieveglobalvariablewidget.h"
-#include "sieveforeverypartwidget.h"
-#include "sievescriptpage.h"
-#include "sieveincludewidget.h"
 #include "sieveeditorgraphicalmodewidget.h"
-#include <QXmlStreamReader>
-#include <QHBoxLayout>
-#include <KMessageBox>
+#include "sieveforeverypartwidget.h"
+#include "sieveglobalvariablewidget.h"
+#include "sieveincludewidget.h"
+#include "sievescriptdescriptiondialog.h"
+#include "sievescriptpage.h"
 #include <KLocalizedString>
+#include <KMessageBox>
+#include <QHBoxLayout>
+#include <QIcon>
 #include <QInputDialog>
 #include <QPushButton>
-#include <QIcon>
+#include <QXmlStreamReader>
 
-#include <QVBoxLayout>
-#include <QListWidget>
-#include <QPointer>
-#include <QMenu>
 #include "libksieve_debug.h"
+#include <QListWidget>
+#include <QMenu>
+#include <QPointer>
+#include <QVBoxLayout>
 
-namespace {
+namespace
+{
 inline const QString defaultScriptName()
 {
     return QStringLiteral("SCRIPTNAME: ");
@@ -85,7 +86,7 @@ QString SieveScriptListItem::generatedScript(QStringList &required) const
 SieveScriptListBox::SieveScriptListBox(const QString &title, QWidget *parent)
     : QGroupBox(title, parent)
 {
-    auto *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
     layout->setObjectName(QStringLiteral("layout"));
     mSieveListScript = new QListWidget(this);
     mSieveListScript->setObjectName(QStringLiteral("mSieveListScript"));
@@ -95,8 +96,8 @@ SieveScriptListBox::SieveScriptListBox(const QString &title, QWidget *parent)
     layout->addWidget(mSieveListScript);
 
     //----------- the first row of buttons
-    QWidget *hb = new QWidget(this);
-    auto *hbHBoxLayout = new QHBoxLayout(hb);
+    auto hb = new QWidget(this);
+    auto hbHBoxLayout = new QHBoxLayout(hb);
     hbHBoxLayout->setContentsMargins({});
     hbHBoxLayout->setSpacing(4);
 
@@ -208,7 +209,7 @@ void SieveScriptListBox::setSieveEditorGraphicalModeWidget(SieveEditorGraphicalM
 void SieveScriptListBox::slotItemActived(QListWidgetItem *item)
 {
     if (item) {
-        auto *itemScript = static_cast<SieveScriptListItem *>(item);
+        auto itemScript = static_cast<SieveScriptListItem *>(item);
         Q_EMIT activatePage(itemScript->scriptPage());
     }
 }
@@ -232,9 +233,9 @@ void SieveScriptListBox::updateButtons()
 
 SieveScriptPage *SieveScriptListBox::createNewScript(const QString &newName, const QString &description)
 {
-    auto *item = new SieveScriptListItem(newName, mSieveListScript);
+    auto item = new SieveScriptListItem(newName, mSieveListScript);
     item->setDescription(description);
-    auto *page = new SieveScriptPage(mSieveGraphicalModeWidget);
+    auto page = new SieveScriptPage(mSieveGraphicalModeWidget);
     page->setListOfIncludeFile(mSieveGraphicalModeWidget->listOfIncludeFile());
     item->setScriptPage(page);
     Q_EMIT addNewPage(page);
@@ -257,9 +258,9 @@ void SieveScriptListBox::slotDelete()
 {
     QListWidgetItem *item = mSieveListScript->currentItem();
     if (item) {
-        if (KMessageBox::warningYesNo(this, i18n("Do you want to delete \"%1\" script?", item->text()),
-                                      i18nc("@title:window", "Delete Script")) == KMessageBox::Yes) {
-            auto *itemScript = static_cast<SieveScriptListItem *>(item);
+        if (KMessageBox::warningYesNo(this, i18n("Do you want to delete \"%1\" script?", item->text()), i18nc("@title:window", "Delete Script"))
+            == KMessageBox::Yes) {
+            auto itemScript = static_cast<SieveScriptListItem *>(item);
             Q_EMIT removePage(itemScript->scriptPage());
             delete item;
             Q_EMIT enableButtonOk(mSieveListScript->count() > 0);
@@ -273,7 +274,8 @@ void SieveScriptListBox::slotRename()
 {
     QListWidgetItem *item = mSieveListScript->currentItem();
     if (item) {
-        QString newName = QInputDialog::getText(this, i18nc("@title:window", "Rename Script"), i18n("New name for the script:"), QLineEdit::Normal, item->text());
+        QString newName =
+            QInputDialog::getText(this, i18nc("@title:window", "Rename Script"), i18n("New name for the script:"), QLineEdit::Normal, item->text());
         newName = newName.trimmed();
         if (!newName.isEmpty()) {
             item->setText(newName);
@@ -286,7 +288,7 @@ void SieveScriptListBox::slotEditDescription()
 {
     QListWidgetItem *item = mSieveListScript->currentItem();
     if (item) {
-        auto *sieveItem = static_cast<SieveScriptListItem *>(item);
+        auto sieveItem = static_cast<SieveScriptListItem *>(item);
         QPointer<SieveScriptDescriptionDialog> dlg = new SieveScriptDescriptionDialog(this);
         dlg->setDescription(sieveItem->description());
         if (dlg->exec()) {
@@ -359,7 +361,7 @@ QString SieveScriptListBox::generatedScript(QStringList &requireModules) const
     QStringList lstRequires;
     const int numberOfScripts(mSieveListScript->count());
     for (int i = 0; i < numberOfScripts; ++i) {
-        auto *item = static_cast<SieveScriptListItem *>(mSieveListScript->item(i));
+        auto item = static_cast<SieveScriptListItem *>(mSieveListScript->item(i));
         if (i != 0) {
             resultScript += QLatin1String("\n\n");
         }
@@ -385,7 +387,7 @@ void SieveScriptListBox::clear()
 {
     mScriptNumber = 0;
     Q_EMIT enableButtonOk(false);
-    //Clear tabpage
+    // Clear tabpage
     mSieveListScript->clear();
     updateButtons();
 }
@@ -411,16 +413,16 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
     bool previousElementWasAComment = false;
     while (n.readNextStartElement()) {
         const QStringRef tagName = n.name();
-        //qDebug() <<"SieveScriptListBox::loadBlock tagName " << tagName;
+        // qDebug() <<"SieveScriptListBox::loadBlock tagName " << tagName;
         if (tagName == QLatin1String("control")) {
             previousElementWasAComment = false;
-            //Create a new page when before it was "onlyactions"
+            // Create a new page when before it was "onlyactions"
             if (typeBlock == TypeBlockAction) {
                 currentPage = nullptr;
             }
             if (n.attributes().hasAttribute(QLatin1String("name"))) {
                 const QString controlType = n.attributes().value(QLatin1String("name")).toString();
-                //qCDebug(LIBKSIEVE_LOG)<<" controlType"<<controlType;
+                // qCDebug(LIBKSIEVE_LOG)<<" controlType"<<controlType;
                 if (controlType == QLatin1String("if")) {
                     typeBlock = TypeBlockIf;
                     if (!currentPage || hasCreatedAIfBlock) {
@@ -449,7 +451,7 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
                     if (blockWidget) {
                         blockWidget->loadScript(n, false, error);
                     }
-                    //We are sure that we can't have another elsif
+                    // We are sure that we can't have another elsif
                     currentPage = nullptr;
                 } else if (controlType == QLatin1String("foreverypart")) {
                     typeBlock = TypeBlockForeachBlock;
@@ -462,14 +464,14 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
                     } else {
                         error += i18n("forEveryPart is not supported by your server") + QLatin1Char('\n');
                     }
-                    //TODO verify it.
+                    // TODO verify it.
 #ifdef QDOMELEMENT_FIXME
                     QDomNode block = e.firstChildElement(QStringLiteral("block")).firstChild();
                     loadBlock(block, currentPage, typeBlock, error);
 #endif
                 } else if (controlType == QLatin1String("require")) {
                     n.skipCurrentElement();
-                    //Nothing. autogenerated
+                    // Nothing. autogenerated
                 } else {
                     qCDebug(LIBKSIEVE_LOG) << " unknown controlType :" << controlType;
                 }
@@ -478,9 +480,9 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
             previousElementWasAComment = true;
 #ifdef FIXME_COMMENT
             if (e.hasAttribute(QStringLiteral("hash"))) {
-                //TODO
+                // TODO
             } else if (e.hasAttribute(QStringLiteral("bracket"))) {
-                //TODO
+                // TODO
             }
 #endif
             QString str(n.readElementText());
@@ -492,7 +494,7 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
                 }
                 comment += str;
             }
-            //qDebug() << " COMMENT " << comment;
+            // qDebug() << " COMMENT " << comment;
         } else if (tagName == QLatin1String("action")) {
             previousElementWasAComment = false;
             if (n.attributes().hasAttribute(QLatin1String("name"))) {
@@ -520,7 +522,7 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
                         qCDebug(LIBKSIEVE_LOG) << " globalVariable not supported";
                     }
                 } else if (actionName == QLatin1String("set") && (typeBlock == TypeBlockGlobal)) {
-                    //FIXME global not global variable.
+                    // FIXME global not global variable.
                     if (currentPage->globalVariableWidget()) {
                         const SieveGlobalVariableActionWidget::VariableElement var = currentPage->globalVariableWidget()->loadSetVariable(n, error);
                         if (var.isValid()) {
@@ -545,7 +547,7 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
                 }
             }
         } else if (tagName == QLatin1String("crlf")) {
-            //If it was a comment previously you will create a \n
+            // If it was a comment previously you will create a \n
             if (previousElementWasAComment) {
                 comment += QLatin1Char('\n');
             }
