@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,13 +9,14 @@
 
 #include <QTabWidget>
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveScriptTabWidget : public QTabWidget
 {
     Q_OBJECT
 public:
     explicit SieveScriptTabWidget(QWidget *parent = nullptr);
-    ~SieveScriptTabWidget();
+    ~SieveScriptTabWidget() override;
 
 private Q_SLOTS:
     void slotTabContextMenuRequest(const QPoint &);
