@@ -7,22 +7,23 @@
 */
 
 #include "sievedebugdialog.h"
-#include <KPIMTextEdit/PlainTextEditorWidget>
-#include <KPIMTextEdit/PlainTextEditor>
+#include "util/findaccountinfojob.h"
 #include "util/util_p.h"
+#include <KPIMTextEdit/PlainTextEditor>
+#include <KPIMTextEdit/PlainTextEditorWidget>
 
 #include "libksieve_debug.h"
 #include <KLocalizedString>
-#include <kmanagesieve/sievejob.h>
-#include <KSyntaxHighlighting/SyntaxHighlighter>
 #include <KSyntaxHighlighting/Definition>
+#include <KSyntaxHighlighting/SyntaxHighlighter>
 #include <KSyntaxHighlighting/Theme>
+#include <kmanagesieve/sievejob.h>
 
-#include <QTimer>
+#include <KConfigGroup>
 #include <KSharedConfig>
 #include <QDialogButtonBox>
-#include <KConfigGroup>
 #include <QPushButton>
+#include <QTimer>
 #include <QVBoxLayout>
 
 using namespace KSieveUi;
@@ -32,7 +33,7 @@ SieveDebugDialog::SieveDebugDialog(SieveImapPasswordProvider *passwordProvider,
     , mPasswordProvider(passwordProvider)
 {
     setWindowTitle(i18nc("@title:window", "Sieve Diagnostics"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
     // Collect all accounts
     mResourceIdentifier = KSieveUi::Util::sieveImapResourceNames();
@@ -44,13 +45,12 @@ SieveDebugDialog::SieveDebugDialog(SieveImapPasswordProvider *passwordProvider,
         qCWarning(LIBKSIEVE_LOG) << "Invalid definition name";
     }
 
-    auto *hl = new KSyntaxHighlighting::SyntaxHighlighter(mEdit->editor()->document());
-    hl->setTheme((palette().color(QPalette::Base).lightness() < 128)
-                 ? mRepo.defaultTheme(KSyntaxHighlighting::Repository::DarkTheme)
-                 : mRepo.defaultTheme(KSyntaxHighlighting::Repository::LightTheme));
+    auto hl = new KSyntaxHighlighting::SyntaxHighlighter(mEdit->editor()->document());
+    hl->setTheme((palette().color(QPalette::Base).lightness() < 128) ? mRepo.defaultTheme(KSyntaxHighlighting::Repository::DarkTheme)
+                                                                     : mRepo.defaultTheme(KSyntaxHighlighting::Repository::LightTheme));
     hl->setDefinition(def);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &SieveDebugDialog::reject);
 
     mainLayout->addWidget(mEdit);
@@ -111,13 +111,21 @@ void SieveDebugDialog::slotDiagNextAccount()
         connect(mShutDownJob, &QTimer::timeout, this, &SieveDebugDialog::slotShutDownJob);
     }
     mShutDownJob->start(30 * 1000); // 30 seconds
-    QString ident = mResourceIdentifier.first();
+    const QString ident = mResourceIdentifier.first();
 
     mEdit->editor()->appendPlainText(i18n("Collecting data for account '%1'...\n", ident));
     mEdit->editor()->appendPlainText(i18n("------------------------------------------------------------\n"));
 
+    auto job = new FindAccountInfoJob(this);
+    connect(job, &FindAccountInfoJob::findAccountInfoFinished, this, &SieveDebugDialog::slotFindAccountInfoFinished);
+    job->setIdentifier(ident);
+    job->setProvider(mPasswordProvider);
+    job->start();
+}
+
+void SieveDebugDialog::slotFindAccountInfoFinished(const KSieveUi::Util::AccountInfo &info)
+{
     // Detect URL for this IMAP account
-    const KSieveUi::Util::AccountInfo info = KSieveUi::Util::fullAccountInfo(ident, mPasswordProvider);
     const QUrl url = info.sieveUrl;
     if (!url.isValid()) {
         mEdit->editor()->appendPlainText(i18n("(Account does not support Sieve)\n\n"));
@@ -126,8 +134,8 @@ void SieveDebugDialog::slotDiagNextAccount()
 
         mSieveJob = KManageSieve::SieveJob::list(mUrl);
 
-        //Laurent: not necessary as it's a readonly dialog
-        //mSieveJob->setProperty("sieveimapaccountsettings", QVariant::fromValue(info.sieveImapAccountSettings));
+        // Laurent: not necessary as it's a readonly dialog
+        // mSieveJob->setProperty("sieveimapaccountsettings", QVariant::fromValue(info.sieveImapAccountSettings));
         connect(mSieveJob, &KManageSieve::SieveJob::gotList, this, &SieveDebugDialog::slotGetScriptList);
 
         // Bypass the singleShot timer -- it's fired when we get our data
@@ -149,15 +157,25 @@ void SieveDebugDialog::slotDiagNextScript()
         return;
     }
 
-    QString scriptFile = mScriptList.constFirst();
+    const QString scriptFile = mScriptList.constFirst();
     mScriptList.pop_front();
 
     mEdit->editor()->appendPlainText(i18n("Contents of script '%1':\n", scriptFile));
 
-    const KSieveUi::Util::AccountInfo info = KSieveUi::Util::fullAccountInfo(mResourceIdentifier.constFirst(), mPasswordProvider);
+    auto job = new FindAccountInfoJob(this);
+    connect(job, &FindAccountInfoJob::findAccountInfoFinished, this, &SieveDebugDialog::slotFindAccountInfoForScriptFinished);
+    job->setIdentifier(mResourceIdentifier.constFirst());
+    job->setProvider(mPasswordProvider);
+    job->setProperty("scriptfile", scriptFile);
+    job->start();
+}
+
+void SieveDebugDialog::slotFindAccountInfoForScriptFinished(const KSieveUi::Util::AccountInfo &info)
+{
     mUrl = info.sieveUrl;
 
     mUrl = mUrl.adjusted(QUrl::RemoveFilename);
+    const QString scriptFile = sender()->property("scriptfile").toString();
     mUrl.setPath(mUrl.path() + QLatin1Char('/') + scriptFile);
 
     mSieveJob = KManageSieve::SieveJob::get(mUrl);
@@ -167,32 +185,22 @@ void SieveDebugDialog::slotDiagNextScript()
 
 void SieveDebugDialog::slotGetScript(KManageSieve::SieveJob *job, bool success, const QString &script, bool active)
 {
-    qCDebug(LIBKSIEVE_LOG) << "( ??," << success
-                           << ", ?," << active << ")"
-                          #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-        << endl
-                          #else
-        << Qt::endl
-                          #endif
-        << "script:"
-                          #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-        << endl
-                          #else
-        << Qt::endl
-                          #endif
-        << script;
+    qCDebug(LIBKSIEVE_LOG) << "( ??," << success << ", ?," << active << ")" << Qt::endl << "script:" << Qt::endl << script;
     mSieveJob = nullptr; // job deletes itself after returning from this slot!
 
     if (!success) {
-        mEdit->editor()->appendPlainText(i18n("Retrieving the script failed.\n"
-                                              "The server responded:\n%1", job->errorString()));
+        mEdit->editor()->appendPlainText(
+            i18n("Retrieving the script failed.\n"
+                 "The server responded:\n%1",
+                 job->errorString()));
     } else if (script.isEmpty()) {
         mEdit->editor()->appendPlainText(i18n("(This script is empty)\n\n"));
     } else {
-        mEdit->editor()->appendPlainText(i18n(
-                                             "------------------------------------------------------------\n"
-                                             "%1\n"
-                                             "------------------------------------------------------------\n\n", script));
+        mEdit->editor()->appendPlainText(
+            i18n("------------------------------------------------------------\n"
+                 "%1\n"
+                 "------------------------------------------------------------\n\n",
+                 script));
     }
 
     // Fetch next script
@@ -204,8 +212,7 @@ void SieveDebugDialog::slotGetScriptList(KManageSieve::SieveJob *job, bool succe
     if (mShutDownJob->isActive()) {
         mShutDownJob->stop();
     }
-    qCDebug(LIBKSIEVE_LOG) << "Success:" << success << ", List:" << scriptList.join(QLatin1Char(','))
-                           <<", active:" << activeScript;
+    qCDebug(LIBKSIEVE_LOG) << "Success:" << success << ", List:" << scriptList.join(QLatin1Char(',')) << ", active:" << activeScript;
     mSieveJob = nullptr; // job deletes itself after returning from this slot!
 
     mEdit->editor()->appendPlainText(i18n("Sieve capabilities:\n"));
