@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -11,14 +11,15 @@
 
 class QAction;
 class QMenu;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveEditorTextModeWidget;
 class SieveEditorMenuBar : public QMenuBar
 {
     Q_OBJECT
 public:
     explicit SieveEditorMenuBar(QWidget *parent = nullptr);
-    ~SieveEditorMenuBar();
+    ~SieveEditorMenuBar() override;
 
     Q_REQUIRED_RESULT QAction *goToLineAction() const;
     Q_REQUIRED_RESULT QAction *findAction() const;
