@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -9,7 +9,8 @@
 
 #include <sonnet/spellcheckdecorator.h>
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveTextEdit;
 class SieveTextEditorSpellCheckDecorator : public Sonnet::SpellCheckDecorator
 {
@@ -17,6 +18,7 @@ class SieveTextEditorSpellCheckDecorator : public Sonnet::SpellCheckDecorator
 public:
     explicit SieveTextEditorSpellCheckDecorator(SieveTextEdit *plainTextEdit);
     Q_REQUIRED_RESULT bool isSpellCheckingEnabledForBlock(const QString &textBlock) const override;
+
 private:
     SieveTextEdit *const mPlainTextEdit;
 };
