@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,13 +8,14 @@
 
 #include <KMessageWidget>
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveEditorWarning : public KMessageWidget
 {
     Q_OBJECT
 public:
     explicit SieveEditorWarning(QWidget *parent = nullptr);
-    ~SieveEditorWarning();
+    ~SieveEditorWarning() override;
 };
 }
 
