@@ -1,5 +1,5 @@
 /* SPDX-FileCopyrightText: 2010 Torgny Nyblom <nyblom@kde.org>
- * SPDX-FileCopyrightText: 2010-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2010-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -7,16 +7,18 @@
 #ifndef FINDBARBASE_H
 #define FINDBARBASE_H
 
-#include <QWidget>
 #include "ksieveui_export.h"
+#include <QWidget>
 class QAction;
 class QPushButton;
 class QMenu;
 class QLabel;
-namespace PimCommon {
+namespace PimCommon
+{
 class LineEditWithCompleterNg;
 }
-namespace KSieveUi {
+namespace KSieveUi
+{
 class KSIEVEUI_EXPORT FindBarBase : public QWidget
 {
     Q_OBJECT
