@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -8,7 +8,8 @@
 #define PARSEUSERJOBTEST_H
 
 #include <QObject>
-namespace KSieveUi {
+namespace KSieveUi
+{
 class ParseUserTest : public QObject
 {
     Q_OBJECT
