@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -7,23 +7,26 @@
 #ifndef PARSEUSERSCRIPTJOB_H
 #define PARSEUSERSCRIPTJOB_H
 
-#include <QObject>
-#include <QUrl>
-#include <QStringList>
 #include "ksieveui_private_export.h"
-namespace KManageSieve {
+#include <QObject>
+#include <QStringList>
+#include <QUrl>
+namespace KManageSieve
+{
 class SieveJob;
 }
 class QXmlStreamReader;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class KSIEVEUI_TESTS_EXPORT ParseUserScriptJob : public QObject
 {
     Q_OBJECT
 
     friend class ParseUserTest;
+
 public:
     explicit ParseUserScriptJob(const QUrl &url, QObject *parent = nullptr);
-    ~ParseUserScriptJob();
+    ~ParseUserScriptJob() override;
 
     void start();
     void setAutoDelete(bool deleteMe);
