@@ -1,13 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sieveimapinstanceinterfacemanagertest.h"
-#include <KSieveUi/SieveImapInstanceInterfaceManager>
 #include <KSieveUi/SieveImapInstance>
 #include <KSieveUi/SieveImapInstanceInterface>
+#include <KSieveUi/SieveImapInstanceInterfaceManager>
 #include <QTest>
 
 SieveImapInstanceInterfaceManagerTest::SieveImapInstanceInterfaceManagerTest(QObject *parent)
@@ -27,7 +27,7 @@ void SieveImapInstanceInterfaceManagerTest::shouldHaveDefaultValue()
 void SieveImapInstanceInterfaceManagerTest::shouldAssignSieveImapInstanceInterface()
 {
     KSieveUi::SieveImapInstanceInterfaceManager manager;
-    auto *instance = new KSieveUi::SieveImapInstanceInterface();
+    auto instance = new KSieveUi::SieveImapInstanceInterface();
     manager.setSieveImapInstanceInterface(instance);
     QVERIFY(manager.sieveImapInstanceInterface());
     QCOMPARE(manager.sieveImapInstanceInterface(), instance);
