@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #include "sievescriptdebuggerdialog.h"
 #include "sievescriptdebuggerwidget.h"
 
-#include <KLocalizedString>
 #include <KConfigGroup>
+#include <KLocalizedString>
 #include <KSharedConfig>
 
 #include <QDialogButtonBox>
@@ -20,7 +20,7 @@ using namespace KSieveUi;
 SieveScriptDebuggerDialog::SieveScriptDebuggerDialog(QWidget *parent)
     : QDialog(parent)
 {
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     setWindowTitle(i18nc("@title:window", "Debug Sieve Script"));
 
     mSieveScriptDebuggerWidget = new SieveScriptDebuggerWidget(this);
@@ -28,7 +28,7 @@ SieveScriptDebuggerDialog::SieveScriptDebuggerDialog(QWidget *parent)
     mainLayout->addWidget(mSieveScriptDebuggerWidget);
     connect(mSieveScriptDebuggerWidget, &SieveScriptDebuggerWidget::sieveTestNotFound, this, &SieveScriptDebuggerDialog::updateButtons);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     mainLayout->addWidget(buttonBox);
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
     mOkButton = buttonBox->button(QDialogButtonBox::Ok);
@@ -106,8 +106,6 @@ void SieveScriptDebuggerDialog::readConfig()
     if (sizeDialog.isValid()) {
         resize(sizeDialog);
     }
-    const QList<int> size {
-        100, 400
-    };
+    const QList<int> size{100, 400};
     mSieveScriptDebuggerWidget->setSplitterSizes(group.readEntry("Splitter", size));
 }
