@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,11 +7,12 @@
 #ifndef SIEVESCRIPTDEBUGGERWIDGET_H
 #define SIEVESCRIPTDEBUGGERWIDGET_H
 
-#include <QWidget>
 #include "ksieveui_export.h"
+#include <QWidget>
 class QStackedWidget;
 class QLabel;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveScriptDebuggerFrontEndWidget;
 /**
  * @brief The SieveScriptDebuggerWidget class
@@ -22,7 +23,7 @@ class KSIEVEUI_EXPORT SieveScriptDebuggerWidget : public QWidget
     Q_OBJECT
 public:
     explicit SieveScriptDebuggerWidget(QWidget *parent = nullptr);
-    ~SieveScriptDebuggerWidget();
+    ~SieveScriptDebuggerWidget() override;
 
     void setScript(const QString &script);
     Q_REQUIRED_RESULT QString script() const;
