@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,8 +9,10 @@
 
 #include "sievetemplatewidget.h"
 
-namespace KSieveUi {
-namespace SieveDefaultTemplate {
+namespace KSieveUi
+{
+namespace SieveDefaultTemplate
+{
 Q_REQUIRED_RESULT QVector<PimCommon::defaultTemplate> defaultTemplates();
 }
 }
