@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,11 +9,13 @@
 
 #include <PimCommon/TemplateListWidget>
 
-namespace PimCommon {
+namespace PimCommon
+{
 class TemplateManager;
 }
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveTemplateListWidget : public PimCommon::TemplateListWidget
 {
     Q_OBJECT
@@ -25,8 +27,10 @@ public:
     Q_REQUIRED_RESULT bool addNewTemplate(QString &templateName, QString &templateScript) override;
     Q_REQUIRED_RESULT bool modifyTemplate(QString &templateName, QString &templateScript, bool defaultTemplate) override;
     void setSieveCapabilities(const QStringList &capabilities);
+
 protected:
     QMimeData *mimeData(const QList<QListWidgetItem *> items) const override;
+
 private:
     QStringList mCapabilities;
     PimCommon::TemplateManager *mTemplateManager = nullptr;
