@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -9,10 +9,12 @@
 
 #include <QStringList>
 
-namespace KSieveUi {
-namespace Test {
+namespace KSieveUi
+{
+namespace Test
+{
 QStringList fullCapabilitiesList();
 }
 }
 
-#endif //KSIEVEUITESTSCAPABILITY_H
+#endif // KSIEVEUITESTSCAPABILITY_H
