@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class RegExpConverterTest : public QObject
     Q_OBJECT
 public:
     explicit RegExpConverterTest(QObject *parent = nullptr);
-    ~RegExpConverterTest() = default;
+    ~RegExpConverterTest() override = default;
 private Q_SLOTS:
     void convertRegExp_data();
     void convertRegExp();
