@@ -1,26 +1,26 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "multiimapvacationdialog.h"
-#include "vacationpagewidget.h"
 #include "multiimapvacationmanager.h"
+#include "vacation/searchserverwithvacationsupportjob.h"
+#include "vacationpagewidget.h"
 
 #include <KLocalizedString>
-#include <KSharedConfig>
 #include <KMessageBox>
+#include <KSharedConfig>
 #include <QTabWidget>
 
-#include <QTabBar>
-#include <QApplication>
-#include <QStackedWidget>
-#include <QVBoxLayout>
-#include <QLabel>
 #include <KConfigGroup>
 #include <QDialogButtonBox>
+#include <QLabel>
 #include <QPushButton>
+#include <QStackedWidget>
+#include <QTabBar>
+#include <QVBoxLayout>
 
 using namespace KSieveUi;
 
@@ -51,7 +51,6 @@ MultiImapVacationDialog::MultiImapVacationDialog(MultiImapVacationManager *manag
 MultiImapVacationDialog::~MultiImapVacationDialog()
 {
     writeConfig();
-    delete d;
 }
 
 void MultiImapVacationDialog::switchToServerNamePage(const QString &serverName)
@@ -69,14 +68,12 @@ void MultiImapVacationDialog::reject()
 {
     bool canCloseDialog = true;
     for (int i = 0; i < d->mTabWidget->count(); ++i) {
-        auto *vacationPage = qobject_cast<VacationPageWidget *>(d->mTabWidget->widget(i));
+        auto vacationPage = qobject_cast<VacationPageWidget *>(d->mTabWidget->widget(i));
         if (vacationPage) {
             if (vacationPage->wasChanged()) {
-                if (KMessageBox::questionYesNo(
-                        this,
-                        i18nc("@info", "Do you really want to cancel?"),
-                        i18nc("@title:window", "Confirmation")) == KMessageBox::Yes) {
-                    QDialog::reject();     // Discard current changes
+                if (KMessageBox::questionYesNo(this, i18nc("@info", "Do you really want to cancel?"), i18nc("@title:window", "Confirmation"))
+                    == KMessageBox::Yes) {
+                    QDialog::reject(); // Discard current changes
                 }
                 canCloseDialog = false;
                 break;
@@ -96,21 +93,22 @@ QVector<VacationCreateScriptJob *> MultiImapVacationDialog::listCreateJob() cons
 void MultiImapVacationDialog::init()
 {
     d->mStackedWidget = new QStackedWidget;
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(d->mStackedWidget);
     d->mTabWidget = new QTabWidget;
     d->mStackedWidget->addWidget(d->mTabWidget);
 
-    QWidget *w = new QWidget;
-    auto *vbox = new QVBoxLayout;
+    auto w = new QWidget;
+    auto vbox = new QVBoxLayout;
     w->setLayout(vbox);
-    QLabel *lab = new QLabel(i18n("KMail's Out of Office Reply functionality relies on "
-                                  "server-side filtering. You have not yet configured an "
-                                  "IMAP server for this. "
-                                  "You can do this on the \"Filtering\" tab of the IMAP "
-                                  "account configuration."));
+    auto lab =
+        new QLabel(i18n("KMail's Out of Office Reply functionality relies on "
+                        "server-side filtering. You have not yet configured an "
+                        "IMAP server for this. "
+                        "You can do this on the \"Filtering\" tab of the IMAP "
+                        "account configuration."));
     lab->setWordWrap(true);
-    lab->setAlignment(Qt::AlignHCenter|Qt::AlignVCenter);
+    lab->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
     QFont font = lab->font();
     font.setBold(true);
     font.setPointSize(font.pointSize() + 2);
@@ -119,10 +117,27 @@ void MultiImapVacationDialog::init()
     lab->setWordWrap(true);
     d->mStackedWidget->addWidget(w);
     d->mStackedWidget->setCurrentIndex(0);
+    mButtonBox = new QDialogButtonBox(this);
+    mButtonBox->setObjectName(QStringLiteral("mButtonBox"));
+    mainLayout->addWidget(mButtonBox);
+    initialize();
+}
+
+void MultiImapVacationDialog::initialize()
+{
+    auto job = new SearchServerWithVacationSupportJob(this);
+    job->setPasswordProvider(d->mVacationManager->passwordProvider());
+    connect(job,
+            &SearchServerWithVacationSupportJob::searchServerWithVacationSupportFinished,
+            this,
+            &MultiImapVacationDialog::slotSearchServerWithVacationSupportFinished);
+    job->start();
+}
+
+void MultiImapVacationDialog::slotSearchServerWithVacationSupportFinished(const QMap<QString, KSieveUi::Util::AccountInfo> &list)
+{
     bool foundOneImap = false;
-    QDialogButtonBox *buttonBox = nullptr;
 
-    const QMap <QString, KSieveUi::Util::AccountInfo> list = d->mVacationManager->serverList();
     QMapIterator<QString, KSieveUi::Util::AccountInfo> i(list);
     while (i.hasNext()) {
         i.next();
@@ -130,20 +145,19 @@ void MultiImapVacationDialog::init()
         foundOneImap = true;
     }
     if (foundOneImap) {
-        buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults, this);
-        QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+        mButtonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults);
+        QPushButton *okButton = mButtonBox->button(QDialogButtonBox::Ok);
         okButton->setDefault(true);
         okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
-        connect(buttonBox, &QDialogButtonBox::accepted, this, &MultiImapVacationDialog::slotOkClicked);
-        connect(buttonBox, &QDialogButtonBox::rejected, this, &MultiImapVacationDialog::slotCanceled);
-        connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked, this, &MultiImapVacationDialog::slotDefaultClicked);
-    } else { //Empty
+        connect(mButtonBox, &QDialogButtonBox::accepted, this, &MultiImapVacationDialog::slotOkClicked);
+        connect(mButtonBox, &QDialogButtonBox::rejected, this, &MultiImapVacationDialog::slotCanceled);
+        connect(mButtonBox->button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked, this, &MultiImapVacationDialog::slotDefaultClicked);
+    } else { // Empty
         d->mStackedWidget->setCurrentIndex(1);
-        buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
-        connect(buttonBox, &QDialogButtonBox::accepted, this, &MultiImapVacationDialog::slotOkClicked);
-        connect(buttonBox, &QDialogButtonBox::rejected, this, &MultiImapVacationDialog::slotCanceled);
+        mButtonBox->setStandardButtons(QDialogButtonBox::Close);
+        connect(mButtonBox, &QDialogButtonBox::accepted, this, &MultiImapVacationDialog::slotOkClicked);
+        connect(mButtonBox, &QDialogButtonBox::rejected, this, &MultiImapVacationDialog::slotCanceled);
     }
-    mainLayout->addWidget(buttonBox);
     if (d->mTabWidget->count() <= 1) {
         d->mTabWidget->tabBar()->hide();
     }
@@ -156,7 +170,7 @@ void MultiImapVacationDialog::slotCanceled()
 
 void MultiImapVacationDialog::createPage(const QString &serverName, const KSieveUi::Util::AccountInfo &info)
 {
-    auto *page = new VacationPageWidget;
+    auto page = new VacationPageWidget;
     page->setServerUrl(info.sieveUrl);
     page->setServerName(serverName);
     page->setVacationManager(d->mVacationManager);
@@ -187,7 +201,7 @@ void MultiImapVacationDialog::slotOkClicked()
     qDeleteAll(d->mListCreateJob);
     d->mListCreateJob.clear();
     for (int i = 0; i < d->mTabWidget->count(); ++i) {
-        auto *vacationPage = qobject_cast<VacationPageWidget *>(d->mTabWidget->widget(i));
+        auto vacationPage = qobject_cast<VacationPageWidget *>(d->mTabWidget->widget(i));
         if (vacationPage) {
             VacationCreateScriptJob *job = vacationPage->writeScript(errorFound);
 
@@ -195,7 +209,7 @@ void MultiImapVacationDialog::slotOkClicked()
                 d->mListCreateJob.append(job);
             }
             if (errorFound) {
-                //Clean up job
+                // Clean up job
                 qDeleteAll(d->mListCreateJob);
                 d->mListCreateJob.clear();
                 break;
@@ -210,7 +224,7 @@ void MultiImapVacationDialog::slotOkClicked()
 void MultiImapVacationDialog::slotDefaultClicked()
 {
     for (int i = 0; i < d->mTabWidget->count(); ++i) {
-        auto *vacationPage = qobject_cast<VacationPageWidget *>(d->mTabWidget->widget(i));
+        auto vacationPage = qobject_cast<VacationPageWidget *>(d->mTabWidget->widget(i));
         if (vacationPage) {
             vacationPage->setDefault();
         }
