@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -11,11 +11,13 @@
 
 #include <QUrl>
 
-namespace KManageSieve {
+namespace KManageSieve
+{
 class SieveJob;
 }
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class ParseUserScriptJob;
 class GenerateGlobalScriptJob;
 class VacationCreateScriptJob : public QObject
@@ -23,7 +25,7 @@ class VacationCreateScriptJob : public QObject
     Q_OBJECT
 public:
     explicit VacationCreateScriptJob(QObject *parent = nullptr);
-    ~VacationCreateScriptJob();
+    ~VacationCreateScriptJob() override;
 
     void start();
     void kill();
