@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -7,13 +7,15 @@
 #ifndef VACATIONPAGEWIDGET_H
 #define VACATIONPAGEWIDGET_H
 
-#include <QWidget>
 #include <QUrl>
+#include <QWidget>
 class QStackedWidget;
-namespace KManageSieve {
+namespace KManageSieve
+{
 }
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class VacationEditWidget;
 class VacationWarningWidget;
 class VacationCreateScriptJob;
@@ -24,7 +26,7 @@ class VacationPageWidget : public QWidget
     Q_OBJECT
 public:
     explicit VacationPageWidget(QWidget *parent = nullptr);
-    ~VacationPageWidget();
+    ~VacationPageWidget() override;
 
     void setServerUrl(const QUrl &url);
     void setServerName(const QString &serverName);
@@ -38,13 +40,7 @@ private Q_SLOTS:
     void slotGetResult(const QString &serverName, const QStringList &sieveCapabilities, const QString &scriptName, const QString &script, bool active);
 
 private:
-
-    void fillWithDefaults();
-
-    enum PageType {
-        Script = 0,
-        ScriptNotSupported = 1
-    };
+    enum PageType { Script = 0, ScriptNotSupported = 1 };
 
     QString mServerName;
     QUrl mUrl;
