@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,16 +7,17 @@
 #ifndef LINEEDITVALIDATOR_H
 #define LINEEDITVALIDATOR_H
 
-#include <QLineEdit>
 #include "ksieveui_private_export.h"
+#include <QLineEdit>
 class QRegularExpressionValidator;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class KSIEVEUI_TESTS_EXPORT LineEditValidator : public QLineEdit
 {
     Q_OBJECT
 public:
     explicit LineEditValidator(QWidget *parent = nullptr);
-    ~LineEditValidator();
+    ~LineEditValidator() override;
 
     Q_REQUIRED_RESULT bool setRegularExpressionPattern(const QString &pattern);
 
