@@ -1,28 +1,17 @@
 /*
-  Copyright (c) 2014-2016 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #ifndef MANAGESIEVEWIDGET_H
 #define MANAGESIEVEWIDGET_H
 #include "ksieveui_export.h"
-
-#include <QUrl>
-
-#include <QWidget>
+#include <KSieveUi/SieveImapAccountSettings>
 #include <QMap>
+#include <QUrl>
+#include <QWidget>
+#include <memory>
 
 class QTreeWidgetItem;
 
@@ -33,35 +22,44 @@ class SieveJob;
 
 namespace KSieveUi
 {
-class SieveImapAccountSettings;
 class ManageSieveTreeView;
 class ManageSieveWidgetPrivate;
 class ParseUserScriptJob;
-
+/**
+ * @brief The ManageSieveWidget class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class KSIEVEUI_EXPORT ManageSieveWidget : public QWidget
 {
     Q_OBJECT
 public:
-    enum SieveEditorMode {
-        NormalEditorMode = 0,
-        Kep14EditorMode
+    enum SieveEditorMode { NormalEditorMode = 0, Kep14EditorMode };
+
+    struct ScriptInfo {
+        QUrl currentUrl;
+        QStringList currentCapabilities;
+        KSieveUi::SieveImapAccountSettings sieveImapAccountSettings;
+        QStringList scriptList;
     };
+
     explicit ManageSieveWidget(QWidget *parent = nullptr);
-    ~ManageSieveWidget();
+    ~ManageSieveWidget() override;
 
     ManageSieveTreeView *treeView() const;
     void enableDisableActions(bool &newScriptAction, bool &editScriptAction, bool &deleteScriptAction, bool &desactivateScriptAction);
 
 Q_SIGNALS:
     void updateButtons(QTreeWidgetItem *item);
-    void newScript(const QUrl &u, const QStringList &currentCapabilities, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings);
-    void editScript(const QUrl &url, const QStringList &currentCapabilities, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings);
+    void newScript(const ScriptInfo &info);
+    void editScript(const ScriptInfo &info);
     void scriptDeleted(const QUrl &u);
     void serverSieveFound(bool imapFound);
     void scriptRenamed(const QUrl &oldUrl, const QUrl &newUrl);
+    void updateSieveSettingsDone();
 
 protected:
     virtual bool refreshList() = 0;
+    virtual void updateSieveSettings() = 0;
 
 private Q_SLOTS:
     void slotItemChanged(QTreeWidgetItem *item, int col);
@@ -91,20 +89,23 @@ protected:
     QMap<QTreeWidgetItem *, QUrl> mUrls;
 
 private:
+    void updateSieveSettingsFinished();
     enum sieveServerStatus {
         SIEVE_SERVER_ERROR = Qt::UserRole + 1,
         SIEVE_SERVER_CAPABILITIES = Qt::UserRole + 2,
         SIEVE_SERVER_MODE = Qt::UserRole + 3,
-        SIEVE_SERVER_IMAP_SETTINGS = Qt::UserRole + 4
+        SIEVE_SERVER_IMAP_SETTINGS = Qt::UserRole + 4,
+        SIEVE_SERVER_LIST_SCRIPT = Qt::UserRole + 5
     };
+    bool canAddNewScript(QTreeWidgetItem *item, bool jobsListIsEmpty);
     bool serverHasError(QTreeWidgetItem *item) const;
     void killAllJobs();
     void clear();
     bool isFileNameItem(QTreeWidgetItem *item) const;
     bool itemIsActived(QTreeWidgetItem *item) const;
     void changeActiveScript(QTreeWidgetItem *item, bool activate);
-
-    ManageSieveWidgetPrivate *const d;
+    void slotGenerateGlobalScriptError(const QString &errorStr);
+    std::unique_ptr<ManageSieveWidgetPrivate> const d;
 };
 }
 
