@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,11 +7,12 @@
 #ifndef MOVEIMAPFOLDERWIDGET_H
 #define MOVEIMAPFOLDERWIDGET_H
 
-#include <QWidget>
-#include <KSieveUi/AbstractMoveImapFolderWidget>
 #include "ksieveui_private_export.h"
+#include <KSieveUi/AbstractMoveImapFolderWidget>
+#include <QWidget>
 class QLineEdit;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveImapAccountSettings;
 class KSIEVEUI_TESTS_EXPORT MoveImapFolderWidget : public KSieveUi::AbstractMoveImapFolderWidget
 {
@@ -24,8 +25,9 @@ public:
     Q_REQUIRED_RESULT QString text() const override;
 
     void setSieveImapAccountSettings(const KSieveUi::SieveImapAccountSettings &account) override;
+
 private:
-    QLineEdit *mLineEdit = nullptr;
+    QLineEdit *const mLineEdit;
 };
 }
 #endif // MOVEIMAPFOLDERWIDGET_H
